@@ -39,8 +39,8 @@ parcor_ijk = function(x, i, j) {
     myn = 1:n
     myp = 1:p
     myk = myp[c(-i, -j)]
-    numij = det(cofactor(x, i, j))
-    numji = det(cofactor(x, j, i))
+    numij = -det(cofactor(x, i, j))
+    numji = -det(cofactor(x, j, i))
     deni = abs(det(cofactor(x, i, i)))
     denj = abs(det(cofactor(x, j, j)))
     ouij = (numij)/sqrt(deni * denj)
